<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Aktiv plegin an',
	'aide_non_disponible' => 'Pati-a bourad la se pa disponib ankò andan lanng la.',
	'auteur' => 'Lotè :',
	'avis_acces_interdit' => 'Entèdiksyon riv isit .',
	'avis_article_modifie' => 'Atansyon, @nom_auteur_modif@ te travaye sou atik-la  @date_diff@ minit pase',
	'avis_aucun_resultat' => 'Okenn rezilta.',
	'avis_chemin_invalide_1' => 'Chemen w te chwazi prann',
	'avis_chemin_invalide_2' => 'li samn pa bon. Mèsi tounyen paj dèyè  pou verifye tout enfomasyon ki w te done.',
	'avis_connexion_echec_1' => 'Koneksyon sou sévè SQL te pa mache.', # MODIF
	'avis_connexion_echec_2' => 'Tounyen dèyè sou paj avan, e gad byen tout enfòmasyon w te bay isit-la mèm.',
	'avis_connexion_echec_3' => '<b>Atansyon</b> Ak enpè sévè sa-yo fòk  w <b>domann</b> ou lébèrgè te aktive laksé labaz SQL, avan w kap itilize ali. Si w vwa se pa posib mèm konek a w, ann gad byen si w te domann ali avan.', # MODIF
	'avis_connexion_ldap_echec_1' => 'Koneksyon sou servè LDAP te pa mache.',
	'avis_connexion_ldap_echec_2' => 'Tounyen dèyè paj avan pou ou byen gade ankò enfòmasyon yo w te doné.',
	'avis_connexion_ldap_echec_3' => 'Ann itilize pa sipò LDAP pou gen enpòt itilizatè yo.', # MODIF
	'avis_deplacement_rubrique' => 'Atansyon ! Ribwik la @contient_breves@ brève@scb@ : si w déplas ali, mési ekri yon krwa po konfirmasyon.',
	'avis_erreur_connexion_mysql' => 'Erè ak koneksyon SQL', # MODIF
	'avis_espace_interdit' => '<b>Espas entèdi</b> <div>SPIP se déja instalé.</div>',
	'avis_lecture_noms_bases_1' => 'Pwogwam pou enstalasyon, li te pa kap fè lekti kouman ki rele bazdone yo, yo ki deja enstale.',
	'avis_lecture_noms_bases_2' => 'Ouswa okenn bazdone se disponib, oswa fonksyon-nan ki pèmè fé lan lis tout bazdone te kraze akòz sekirite
  (genyen anpil lebergè te chwazi ki se ka-a).',
	'avis_lecture_noms_bases_3' => 'Nan dezyèm ka, gen petèt posib itilize yon lòt baz ki rele deja nonkod w sa-a :',
	'avis_non_acces_page' => 'Ou gen pa aksé sou paj la.',
	'avis_operation_echec' => 'Operasyon la te pa mache.',
	'avis_suppression_base' => 'ATANSYON,  sipwesyon tout done-an se pa kav tounen deyé',

	// B
	'bouton_acces_ldap' => 'Ajoute yon aksé LDAP',
	'bouton_ajouter' => 'Ajoute',
	'bouton_demande_publication' => 'Mann atik la i parèt',
	'bouton_desactive_tout' => 'Empeche laktivasyon',
	'bouton_effacer_tout' => 'Kraze TOUT',
	'bouton_envoyer_message' => 'Mesaj se bon : voye',
	'bouton_modifier' => 'Chanje',
	'bouton_radio_afficher' => 'Fé parèt',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Montre w nan lis redaktè yo ap an liy', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Voye anons yo sou adrès la :',
	'bouton_radio_envoi_liste_nouveautes' => 'Voye yon lis nouvèlte yo',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Ann pa aparèt w nan lis redakté yo ap an liy', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Rete voye anons editoyal ',
	'bouton_redirection' => 'TOUNYEN ADRES DEYO',
	'bouton_relancer_installation' => 'Ann eseye ankò instalasyon nan',
	'bouton_suivant' => 'Swivan',
	'bouton_tenter_recuperation' => 'Esèy yon aranjman',
	'bouton_test_proxy' => 'Esèy proksi',
	'bouton_vider_cache' => 'Vid kach-la',

	// C
	'cache_modifiable_webmestre' => 'Webmèt sit-la sèlman li kap chanje paramèt sa-a.', # MODIF
	'calendrier_synchro' => 'Si w itilize yon logisyèl pou en lajenda ki mache ak <b>iCal</b> (Apple iCal, Mozilla Calendar, Ximian Evolution, KOrganizer...), w pé mèt ali swiv yon ritm laktyalité sit-la kan li chanje.',

	// D
	'date_mot_heures' => 'èr yo',

	// E
	'email' => 'limèl',
	'email_2' => 'limèl :',
	'entree_adresse_annuaire' => 'Adrès nan aniyè',
	'entree_adresse_email' => 'ou ladrès limèl',
	'entree_base_donnee_1' => 'Ladrès bazdone',
	'entree_base_donnee_2' => '(Souvan ladrès-la se paréy sak ladrès sitwèb w-a, osnon lès senpman «localhost»,  oubyen lès ali vid.)',
	'entree_biographie' => 'Ki se w (kèk mo sèlman).',
	'entree_chemin_acces' => '<b>Rantre</b> chemen pou aksè :',
	'entree_cle_pgp' => 'Ou klé PGP',
	'entree_contenu_rubrique' => '(Kisa ribrik-la gen kontni nan kèk mo.)',
	'entree_identifiants_connexion' => 'Ou lidantifyan pou koneksyon...',
	'entree_informations_connexion_ldap' => 'Mèsi mèt dann komisyon-la tout enfòmasyon nésesè pou abòd  laniyè LDAP.


Tout informasyon-nan,  komandèr-sistèm ou komandèr-rézo li dwa donn a w.', # MODIF
	'entree_infos_perso' => 'Kouman w rele ?',
	'entree_interieur_rubrique' => 'Andan ribrik-la :',
	'entree_liens_sites' => '<b>Lyen ipètèks</b> (referans, sit pou fè yon vire...)',
	'entree_login' => 'Ou nonkod',
	'entree_login_connexion_1' => 'Nonkod pou koneksyon',
	'entree_login_connexion_2' => '(souvan se nondkod ou pou laksé FTP mèm ; men se posib lès vid)',
	'entree_mot_passe' => 'Ou modpas',
	'entree_mot_passe_1' => 'Modpas pou koneksyon',
	'entree_mot_passe_2' => '(souvan se nondkod ou pou laksé FTP menm ; men se posib lès vid)',
	'entree_nom_fichier' => 'Mési enskri kouman fichye @texte_compresse@ i rele:',
	'entree_nom_pseudo' => 'Kouman w rele',
	'entree_nom_pseudo_1' => '(Kouman w rele)',
	'entree_nom_site' => 'Kouman sit li rele',
	'entree_nouveau_passe' => 'Nouvo modpas',
	'entree_passe_ldap' => 'Modpas',
	'entree_port_annuaire' => 'Niméwo por lanyè',
	'entree_signature' => 'Siyati',
	'entree_titre_obligatoire' => '<b>Kouman bagay la rele</b> [Nesesè]<br />',
	'entree_url' => 'Ladrès (URL) sit-w',
	'erreur_plugin_fichier_absent' => 'Oken fichye',
	'erreur_plugin_fichier_def_absent' => 'Oken fichye pou definisyon an',
	'erreur_plugin_nom_fonction_interdit' => 'Kouman fichiye a rele se entedi  ',
	'erreur_plugin_nom_manquant' => 'W ki pa rele plegin an ',
	'erreur_plugin_tag_plugin_absent' => '&lt;Pa oken plegin an &gt; nan fichye pou définisyon',
	'erreur_plugin_version_manquant' => 'Pa oken vesyon plegin an',

	// I
	'ical_info1' => 'Paj-la ka donn a w kouman w kap gen lyen ak lavi sit-la.',
	'ical_info2' => 'Si w vle dot ranseyman sou tout teknik anlèr, ezit pa gad <a href="@spipnet@">tout paj dokimantasyon pou SPIP</a>.', # MODIF
	'ical_info_calendrier' => 'W genyen dé kalandryé. Promyè sé kart sit-la ki anonsé tout atik piblyé. Lòt dezyèm se kalandryé ka kontni tout anons editoryal yo ak mesaj prive yo ki w te genyen : kalandryé a se résèvè pou w sèlman akoz w gen ositou yon klé pèsònel. Klé ou-a kap chanje nepòt kan w vle pa chanje modpas w-a.',
	'ical_methode_http' => 'Telechajman',
	'ical_methode_webcal' => 'Sinkwonizasyon (webcal://)', # MODIF
	'ical_texte_prive' => 'Kalandriyé a, se sèlman pèsònel, ki enfòm a w kisa se laktivité editoryal pwivé sou sit-la (kisa se ankò pou fè, rannkont lòt patisipan, kisa se atik yo ak tinouvèl ki pwopozé pou piblikasyon...).',
	'ical_texte_public' => 'Kalandriyé a ka pémè w swiv laktivité piblik sou sit la (atik yo ak tinouvèl ositou ki pibliyé).',
	'ical_texte_rss' => 'Ou kap sendiké tout nouvèltè sou sit la nan nepòt kisa lèktè fichyé a ki mache sou fòma XML/RSS (Rich Site Summary). Fòma  se fòma ka pémè SPIP fè lekti tout nouvèlté ki pibliyé sou lòt sit yo ka itilize yon fòma echanj posib (konpatib konsa sit sendiké yo).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Lis-limèl',
	'ical_titre_rss' => 'Fichye yo pou sendikasyon',
	'icone_activer_cookie' => 'Mèt yon gatomakro ',
	'icone_admin_plugin' => 'Jere tout plegin yo',
	'icone_afficher_auteurs' => 'Afiche lotè yo',
	'icone_afficher_visiteurs' => 'Afiche vizitè yo',
	'icone_arret_discussion' => 'Rete sotni kozman-nan',
	'icone_calendrier' => 'Kalandrye',
	'icone_creer_auteur' => 'Kreye yon nouvo lotè ek mèt ali ak atik la',
	'icone_creer_mot_cle' => 'Kreye yon nouvo mokle ek gen yon lyen ak atik la',
	'icone_creer_rubrique_2' => 'Kreye yon nouvo ribrik',
	'icone_modifier_article' => 'Chanje atik la',
	'icone_modifier_rubrique' => 'Chanje ribrik la',
	'icone_retour' => 'Tounyen deyé',
	'icone_retour_article' => 'Tounyen deyé sou atik a',
	'icone_supprimer_cookie' => 'Kraze gatomakro ',
	'icone_supprimer_rubrique' => 'Kraze ribrik la',
	'icone_supprimer_signature' => 'Kraze siyati a',
	'icone_valider_signature' => 'Konfime siyati a',
	'image_administrer_rubrique' => 'Ou kapab gèr ribrik la',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 atik',
	'info_activer_cookie' => 'Ou kapab mèt <b> yon gatomakro ki rokonèt a w</b>, ki ke pèmè 
 fè yon viré ant sit piblik ek sit privé.',
	'info_administrateur' => 'Komandè', # MODIF
	'info_administrateur_1' => 'Komandè', # MODIF
	'info_administrateur_2' => 'sit (<i>atansyon kan w ke itilize ali</i>)',
	'info_administrateur_site_01' => 'Si w se komandè sit-la, mèsi', # MODIF
	'info_administrateur_site_02' => 'klik lyen nan',
	'info_administrateurs' => 'Komandè yo', # MODIF
	'info_administrer_rubrique' => 'Ou kapab gère ribrik-la',
	'info_adresse' => 'sou ladrès :',
	'info_adresse_url' => 'Ladrès(URL) sit piblik',
	'info_aide_en_ligne' => 'Bourad an liy SPIP',
	'info_ajout_image' => 'Kan w vlé ajoute kèk imaj tankou kèk dokiman jwenn sou yon atik,
 Spip kap kreye kèk vinyèt ak imaj yo w te mèt sou sit la(kèk piti imaj)otomatikman.Konsa gen posib
 kreye yon galri ou yon pòtfolyo otomatik.
  .',
	'info_ajouter_rubrique' => 'Ajoute yon lòt ribrik pou gére :',
	'info_annonce_nouveautes' => 'Annons nouvèlté yo',
	'info_article' => 'atik',
	'info_article_2' => 'atik yo',
	'info_article_a_paraitre' => 'Atik posdaté yo ki pou parèt',
	'info_articles_02' => 'atik yo',
	'info_articles_2' => 'Atik yo',
	'info_articles_auteur' => 'Tout atik lotè-a ',
	'info_articles_trouves' => 'Atik yo ki te rannkont',
	'info_attente_validation' => 'Atik w-a ki tann komandè konfime',
	'info_aujourdhui' => 'jodiya, :',
	'info_auteurs' => 'Lotè yo',
	'info_auteurs_par_tri' => 'Lotè yo@partri@',
	'info_auteurs_trouves' => 'Lotè yo ki te fin rannkont',
	'info_authentification_externe' => 'Lotantifikasyon déò',
	'info_avertissement' => 'Mesaj pou atansyon',
	'info_base_installee' => 'Strikti bazdone se enstale.',
	'info_chapeau' => 'Chapo',
	'info_chapeau_2' => 'Chapo :',
	'info_chemin_acces_1' => 'Opsyion sa-yo: <b>Chemen pou laksè nan laniyè</b>',
	'info_chemin_acces_2' => 'Ou kapak konfigir chemen laksé sou enfòmasyon sa-yo ki nan laniyè. enfòmasyon-nan sé nésèsè pou fè lekti pwòfil zitilizatè yo ki enskinan laniyè sa-a.', # MODIF
	'info_chemin_acces_annuaire' => 'Opsyon sa-yo : <b>Chemen pou laksè nan lanyè',
	'info_choix_base' => 'Trwazièm etap :',
	'info_classement_1' => '<sup>ye</sup> sou @liste@',
	'info_classement_2' => '<sup>em</sup> sou @liste@',
	'info_code_acces' => 'Oubliy pa kod laksè w-a, pou w mèm !',
	'info_config_suivi' => 'Si ladrès-la ap koresponn yon lis-limèl, w kap enskri isit anba ladès tout patisapan sou sit-la yon ke kap enskri a y. Ladrès-la pétèt se yon URL (pa egsanp lapaj lenskrisyon sou lalis-limèl pa Web-la), osnon yon ladrès limèl ki gen yon sijé spécifik (pa egsanp: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'W kap enskri w pou ou gen lalis-limèl sit-la. Ou ke gen alò yon limèl pou rankont tout anons pou atik-la ek tinouvèl nan sit-la ki pwopozé pou piblikasyon.',
	'info_confirmer_passe' => 'Konfime nouvo modpas-la :',
	'info_connexion_base' => 'Dezyem etap : <b>Esey fè yon koneksyon sou labaz</b>', # MODIF
	'info_connexion_ldap_ok' => 'Koneksyon LDAP te mache.</b><p> Ann gen w etap swivan.</p>', # MODIF
	'info_connexion_mysql' => 'Premye etap : <b>Ou koneksyon SQL</b>', # MODIF
	'info_connexion_ok' => 'Koneksyon nan te fin mache.',
	'info_contact' => 'Kontak',
	'info_contenu_articles' => 'Kisa ap kontni nan atik yo',
	'info_creation_paragraphe' => '(Pou kreye kèk pawagwaf, ann lès kèk liy vid senpman.)', # MODIF
	'info_creation_rubrique' => 'Avan w kapab ekri kèk atik,<br /> fòk w te fin kreye yon ribrik omwen.<br />',
	'info_creation_tables' => 'Katryèm etap : <b>Kreye kèk tab nan bazdone</b>', # MODIF
	'info_creer_base' => '<b>Kreye</b> yon nouvo bazdone :',
	'info_dans_rubrique' => 'Andan ribrik :',
	'info_date_publication_anterieure' => 'Dat li te fin pibliyé avan :',
	'info_date_referencement' => 'DAT SIT-LA TE FIN REFERANSE :',
	'info_derniere_etape' => 'Dènye etap : <b> se fin fini !', # MODIF
	'info_descriptif' => 'Dekrisyon :',
	'info_discussion_cours' => 'Kozman ki ap diskite',
	'info_ecrire_article' => 'Ou dwa dabò kreye yon premyé ribrik avan ekri yon atik.',
	'info_email_envoi' => 'Adrès limèl pour voye yon mesaj (pa oblijé)',
	'info_email_envoi_txt' => 'Ann enskri isit ladrès fòk limèl yo ke rive sou (osnon  ladrès destinatè ke itilise konsa yon ladrès pou lanvwa) :',
	'info_email_webmestre' => 'Ladrès limèl wèbmèt(pa oblije)', # MODIF
	'info_envoi_email_automatique' => 'Pou voye kèk limèl otomatikman',
	'info_envoyer_maintenant' => 'Voye kounye-a touswit',
	'info_etape_suivante' => 'Mach etap swivan',
	'info_etape_suivante_1' => 'Ou kapab mach etap swivan.',
	'info_etape_suivante_2' => 'Ou kapab mach etap swivan.',
	'info_exportation_base' => 'espòtasyon labaz sou  @archive@',
	'info_facilite_suivi_activite' => 'Pou yon swivi fasil lakivité sit-la
, SPIP kapab
 voye tout domann osnon konfimasyon pou fè parèt yon atik pa egsanp nan list-limèl pou redaktè.', # MODIF
	'info_fichiers_authent' => 'Fichye yo pou lotantifikasyon « .htpasswd »',
	'info_forums_abo_invites' => 'Sit w genyen fowom sou abonman ; vizitè   se invite enskri ali sou sit piblik.', # MODIF
	'info_gauche_admin_tech' => '<b>Responsab sit-la selman kapab fè lekti paj-la.</b><p> Li pèrmè laksé pou diféran fonksyon teknik pou swen sit sa-a. Genyen fonksyon sa-yo ki doman yon otantifikasyon espesifik ki doman yon laksé FTP pou sitweb-la.</p>', # MODIF
	'info_gauche_auteurs' => 'Isit, genyen tout zotè sit sa-a.
Koulè imaj rannkont stati yo (komandè = vèr; redaktè = jon).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Tout lòtè andèyò, ki genyen pa aksè sit-la, se afiche pa yon ikòn blè ;
 lòtè yo ki te kraze se yon bwat poubèl.', # MODIF
	'info_gauche_messagerie' => 'Mesajri rann w kapab voye tout mesaj ant redaktè, gade pansbèt (pèsonel) osnon fè parèt annons sou paj akey nan espas prive (si w se komandè).', # MODIF
	'info_gauche_statistiques_referers' => 'Paj-la se paj ki done lis <i>referers</i>, se dir tout sit sa-yo ki genyen lyen ki rive sou sit w, yer ak jodila ; li repar zéwo tout 24èr la.',
	'info_gauche_visiteurs_enregistres' => 'Ou ka rannkont isit vizitè yo ki enskri
 nan espas piblik sit sa-a (fowom sou labonman).',
	'info_generation_miniatures_images' => 'Kreyasyon piti imaj la',
	'info_hebergeur_desactiver_envoi_email' => 'Kèk lebègè ki sispann posibilitè voye kèk limèl otomatikman
  sou sèvè yo-a. Alò, tout fonksyonalité swivan ke pa mache.
',
	'info_hier' => 'yèr :',
	'info_identification_publique' => 'Ou lidantité piblik...',
	'info_image_process' => 'Tanpri chwazi mèyè métod pou lakreyasyon viyèt yo. Pou sa-a mèsi klike sou imaj la ki koresponn.',
	'info_image_process2' => '<b>N.B.</b> <i>Si oken imaj ki parèt, pètèt se sèvè ki ebèj sit ou ki pa konfigire pou itilize outiy sa-yo. Fòk w kontak responsab teknik sèvè an pou domann tout ektansyon «GD» ou «Imagick» sa-yo.</i>', # MODIF
	'info_images_auto' => 'Imaj kalkilé otomatikman',
	'info_informations_personnelles' => 'Sinkyèm etap : <b>Enfòmasyon pèsonel yo</b>', # MODIF
	'info_inscription_automatique' => 'Enskrisyon otomatik pou nouvo redaktè yo', # MODIF
	'info_jeu_caractere' => 'Je kawaktè-liprimiri pou sit sa-a',
	'info_jours' => 'jou yo',
	'info_laisser_champs_vides' => 'lès chan vid yo',
	'info_langues' => 'Tout lanng sit la',
	'info_ldap_ok' => 'Lotantifikasyon LDAP se enstale.',
	'info_lien_hypertexte' => 'Lyen ipètèks :',
	'info_liste_redacteurs_connectes' => 'Llis redaktè ki ap an liy kounye-a', # MODIF
	'info_login_existant' => 'Nonkod la ki egziste deja.',
	'info_login_trop_court' => 'Nondkod ki tro piti.',
	'info_maximum' => 'maksimom :',
	'info_meme_rubrique' => 'Lòt dokiman nan pati sa a nan sit la',
	'info_message_en_redaction' => 'Mesaj w yo ki ap ekri ankò',
	'info_message_technique' => 'Mesaj tèknik :',
	'info_messagerie_interne' => 'Kazmodékri andodan',
	'info_mise_a_niveau_base' => 'Mèt baz SQL nan bon nivo', # MODIF
	'info_mise_a_niveau_base_2' => '{{Tansyon!}} W te instalé yon vèsyon
 fichye SPIP  ki  {pli vyé} vèsyon sa-a ki sou sit avant
: genyen danje bazdone ou ke pèdi osnon li ki pa mache ek sit-la
pa mache mèm.<br />{{Fòk w instal ankò
  yon lot fwa tout fichye spip pli frè.}}',
	'info_modifier_rubrique' => 'Chanje ribrik-la :',
	'info_modifier_titre' => 'Chanje : @titre@',
	'info_mon_site_spip' => 'Sit SPIP a mwen',
	'info_moyenne' => 'mwayèn :',
	'info_multi_cet_article' => 'Lalanng atik la :',
	'info_multi_langues_choisies' => 'Mèsi chwazi lang redaktè kapab itilize
  genyen inposib kraze lang sa-yo ki deja itilize sou sit-la (yo afiche premyé).', # MODIF
	'info_multi_secteurs' => '... sèlman sou ribrik andan rasin sit la ?',
	'info_nom' => 'Kouman i rele',
	'info_nom_destinataire' => 'Kouman destinatè i rele',
	'info_nom_site' => 'Kouman sit la li rele',
	'info_nombre_articles' => '@nb_articles@ atik (yo),',
	'info_nombre_rubriques' => '@nb_rubriques@ ribrik (yo),',
	'info_nombre_sites' => '@nb_sites@ sit (yo),',
	'info_non_deplacer' => 'Mèsi chanje pa laplas-la...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'Spip kapab voye lis dènryè nouvelté sou sit-la
  (tout nouvo atik ak tinouvèl ki pibliyé).',
	'info_non_envoi_liste_nouveautes' => 'Voye pa lis nouvelté.',
	'info_non_modifiable' => 'ki pa posib chanje',
	'info_non_suppression_mot_cle' => 'mwen vle pa kraze mokle-a.',
	'info_notes' => 'Not yo',
	'info_nouvel_article' => 'Nouvo atik',
	'info_nouvelle_traduction' => 'Nouvo tradiksyon :',
	'info_numero_article' => 'ATIK NIMEWO :',
	'info_obligatoire_02' => ' (Nésèsè)', # MODIF
	'info_option_accepter_visiteurs' => 'Asepte vizitè yo enskri y sou sit piblik', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Refize lenskripsyon vizitè yo', # MODIF
	'info_options_avancees' => 'KEK OPSYON PWESI ',
	'info_ou' => 'ou...',
	'info_page_interdite' => 'Paj-la se entèdi',
	'info_par_nom' => 'kritè se kouman rele',
	'info_par_nombre_article' => '(pa nonm artik yo)',
	'info_passe_trop_court' => 'Modpas se tro piti.',
	'info_passes_identiques' => 'Ou dè modpas yo se pa parey sa-mèm.',
	'info_plus_cinq_car' => 'plis de 5 kawaktè-leprimri',
	'info_plus_cinq_car_2' => '(Plis de 5 kawaktè-lenprimri)',
	'info_plus_trois_car' => '(Plis de 3 kawaktè-lenprimri)',
	'info_popularite' => 'kouman se popilè : @popularite@ ; vizit yo : @visites@',
	'info_post_scriptum' => 'Gen di ankò',
	'info_post_scriptum_2' => 'Gen di ankò :',
	'info_pour' => 'pou',
	'info_preview_texte' => 'Posib gad avan sit-la kom si tout atik ek tinouvèl sa-yo (yon ki lestati  « se pwopozé » omwen) te pibliyé an liy. Eske w vle bay posibilite a ouvè  pou tout komandè sèlman, oubyen tout rédaktè, ousinon pa okenn moun sa-mèm ?', # MODIF
	'info_procedez_par_etape' => 'avans etap pa etap',
	'info_procedure_maj_version' => 'fòk w koumans larnouvèlman labaz pou adapte labazdone
 ansamn nouvo vèsyon SPIP.',
	'info_ps' => 'Gen di ankò.',
	'info_publier' => 'pibliye',
	'info_publies' => 'Atik w-a ki ap pibliye an liy',
	'info_question_accepter_visiteurs' => 'Si leskelèt sit w la, li ka pwopoze lenskripsyon vizitè ki pa laksé lespas privé, mèsi w aktive lopsyon issit anba :', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Aksepte ounon pa aksepte w tout enskripsyon nouvo redaktè sou lespas piblik sit-la ?
Si wi ka aksepte, vizité yo ke enskri azot depi
   yon fòmilè,  pou zot ke sere laksé nan espas privé pou zot kapab pwopoze
  zot pwop atik yo a y mèm. <blockquote><i>Kann moun-la zot ap enskri azot,
 y reswa yon limèl otomatik
  ki bay azottout kod laksé sou sit privé. Kèk
  lébèjè ka enpeche lanvwa tout limèl  depi zot sèvè :
  alò, lenskrisyon otomatik ke
  inposib.', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
	'info_racine_site' => 'Rasin sit-la',
	'info_recharger_page' => 'Tapri rochaj paj la nan kèk minit.',
	'info_recherche_auteur_zero' => 'Okenn rezilta pou « @cherche_auteur@ ».',
	'info_recommencer' => 'Mèsi eseye yon lòt fwa.',
	'info_redacteur_1' => 'Redaktè',
	'info_redacteur_2' => 'ki gen laksè nan espas privé (<i>recommandé</i>)',
	'info_redacteurs' => 'Redaktè yo',
	'info_redaction_en_cours' => 'KI AP POU EKRI ANKO',
	'info_redirection' => 'Tounyen déyè sou yon lòt adrès ',
	'info_refuses' => 'Atik w-a ki te finn refize',
	'info_reglage_ldap' => 'Opsyon : <b>Reglaj lempotasyon LDAP</b>',
	'info_renvoi_article' => '<b>Tounyen dèyè sou yon lòt adrès.</b> Atik-la ap sòti sou lapaj-la:',
	'info_reserve_admin' => 'Komandè ysèlman yokapab chanje ladrès-la', # MODIF
	'info_restreindre_rubrique' => 'Diminye drwa yo komandé-a pou li kapab debouye sou ribrik-la sèlman:',
	'info_resultat_recherche' => 'Rezilta chèche w-a :',
	'info_rubriques' => 'Ribrik yo',
	'info_rubriques_02' => 'ribrik yo',
	'info_rubriques_trouvees' => 'Ribrik yo ki te fin rannkont',
	'info_sans_titre' => 'Bagay ki pa rele oken non',
	'info_selection_chemin_acces' => '<b>Chwazi</b> chemen laksé nan laniyè :',
	'info_signatures' => 'siyati yo',
	'info_site' => 'Sit',
	'info_site_2' => 'sit :',
	'info_site_min' => 'sit',
	'info_site_reference_2' => 'Sit referanse',
	'info_site_web' => 'SIT WEB :', # MODIF
	'info_sites' => 'sit yo',
	'info_sites_lies_mot' => 'Sit referanse sa-yo ki jwenn nan lyen ak mokle-a',
	'info_sites_proxy' => 'Itilize yon proksi (proxy)',
	'info_sites_trouves' => 'Sit sa-yo ki te fin rannkont',
	'info_sous_titre' => 'Soutit :',
	'info_statut_administrateur' => 'Komandè', # MODIF
	'info_statut_auteur' => 'Lestati lotè-a :', # MODIF
	'info_statut_redacteur' => 'Redaktè',
	'info_statut_utilisateurs_1' => 'Lestati otomatik pou zitilizatè enpòte yo', # MODIF
	'info_statut_utilisateurs_2' => 'Chwazi stati ki bay smou préan nan laniyé  LDAP, kank moun ka konek azot promyé fwa. Aprésa w kapab chanje valè la pou chak lotè, chaken apré lòt.', # MODIF
	'info_suivi_activite' => 'Swivi laktivité léditoryal',
	'info_surtitre' => 'Sitit :',
	'info_taille_maximale_vignette' => 'Pli gran tay posib pou viyèt sistem sa-a li kreye :',
	'info_terminer_installation' => 'Ou kapab kounyen-a fin fini pwosédi lenstalasyon estanda.',
	'info_texte' => 'Tèks',
	'info_texte_explicatif' => 'Tèks pou esplike',
	'info_texte_long' => '(akoz tèks-la se lon : li afiche nan kèk pat sa-yo, zot ke kenbe ansamn aprè konfimasyon.)',
	'info_texte_message' => 'Tèks pou mesaj-w :', # MODIF
	'info_texte_message_02' => 'Tèks pou mesaj-la',
	'info_titre' => 'Tit (Kouman i rele) :',
	'info_total' => 'kont konple :',
	'info_tous_articles_en_redaction' => 'Tout atik sa-yo ki ap pou ekri ankò',
	'info_tous_articles_presents' => 'Tout atik sa-yo ki pibliye nan ribrik-la',
	'info_tous_les' => 'tout :',
	'info_tout_site' => 'Tout sit sa-mèm',
	'info_tout_site2' => 'Atik-la se pa tradwui nan lalanng la.',
	'info_tout_site3' => 'Atik-la li te tradwi nan lang-la, men kèk chanjman te rive sou latik-referans, apré tradiksyon la. Fòk li ke mont nan nivo.',
	'info_tout_site4' => 'Atik la te tradwi nan lang la, ak tradiksyon se resan ek konple.',
	'info_tout_site5' => 'Atik lorijin.',
	'info_tout_site6' => '<b>Atansyon :</b> atik lorijin se afiche sèlman.
Tout twadiksyon se jwen ak latik lorijin,
nan yon koulè ki bay lestati ali :',
	'info_travail_colaboratif' => 'Soutni ansamn pour atik yo',
	'info_un_article' => 'yon atik,',
	'info_un_site' => 'yon sit,',
	'info_une_rubrique' => 'yon ribrik,',
	'info_une_rubrique_02' => '1 ribrik',
	'info_url' => 'Ladres URL :',
	'info_urlref' => 'Lyen ipètèks :',
	'info_utilisation_spip' => 'Kounyen-a,ou kapab koumanse itilize sistèm pou piblikasyon ki édé...',
	'info_visites_par_mois' => 'Fè parèt pa mwa :',
	'info_visiteur_1' => 'Vizitè',
	'info_visiteur_2' => 'd sit piblik',
	'info_visiteurs' => 'Vizitè yo',
	'info_visiteurs_02' => 'Vizitè yo d sit piblik',
	'install_echec_annonce' => 'Lenstalasyon-an ka pétèt branlan, osnon pétèt li don yon sit ki pa kav mache...',
	'install_extension_mbstring' => 'SPIP ki pa mache ak :',
	'install_extension_php_obligatoire' => 'Fok SPIP li genyen léstansyon php :',
	'install_select_langue' => 'Chwazi yon lang ak piye sou bouton « swivan » pou dmare prosédi-lenstalasyon.',
	'intem_redacteur' => 'redaktè',
	'item_accepter_inscriptions' => 'Asèpt enskripsyon yo',
	'item_activer_messages_avertissement' => 'Aktive mesaj-lavertisman ',
	'item_administrateur_2' => 'komandè', # MODIF
	'item_afficher_calendrier' => 'Fè parèt nan kalandrye',
	'item_choix_administrateurs' => 'komandè yo', # MODIF
	'item_choix_generation_miniature' => 'Kreye otomatikman vèsyon miyati (viyèt) pou tout imaj.',
	'item_choix_non_generation_miniature' => 'Pa kreye miyati pou limaj.',
	'item_choix_redacteurs' => 'redaktè yo',
	'item_choix_visiteurs' => 'vizitè yo d sit piblik',
	'item_creer_fichiers_authent' => 'Kreye fichye yo .htpasswd',
	'item_login' => 'Nonkod',
	'item_mots_cles_association_articles' => 'nan atik yo',
	'item_mots_cles_association_rubriques' => 'nan ribrik yo',
	'item_mots_cles_association_sites' => 'nan sit referanse ou sendiké yo.',
	'item_non' => 'Non',
	'item_non_accepter_inscriptions' => 'Asèpt pa enskripsyon yo',
	'item_non_activer_messages_avertissement' => 'Pa oken mesaj-lavertisman',
	'item_non_afficher_calendrier' => 'Refize parèt nan kalandrye',
	'item_non_creer_fichiers_authent' => 'Kreye pa fichye sa yo',
	'item_non_publier_articles' => 'Pa pibliyé atik sa-yo avan ladat ki présizé.',
	'item_nouvel_auteur' => 'Nouvo lotè',
	'item_nouvelle_rubrique' => 'Nouvo ribrik',
	'item_oui' => 'Wi',
	'item_publier_articles' => 'Fè parèt tout atik kiswa dat piblikasyon ali.',
	'item_reponse_article' => 'Repons sou atik sa-a',
	'item_visiteur' => 'vizitè',

	// J
	'jour_non_connu_nc' => 'ki pa koni',

	// L
	'lien_ajouter_auteur' => 'Ajoute lotè-a',
	'lien_email' => 'limèl',
	'lien_nom_site' => 'KOUMAN SIT-LA RELE :',
	'lien_retirer_auteur' => 'Kraze lotè-a',
	'lien_site' => 'sit',
	'lien_tout_deplier' => 'Dépliye tout',
	'lien_tout_replier' => 'Repliye tout',
	'lien_trier_nom' => 'Fé parèt swivan kouman rele',
	'lien_trier_nombre_articles' => 'Fé parèt swivan nonm atik yo',
	'lien_trier_statut' => 'ranje swivan lestati',
	'lien_voir_en_ligne' => 'GAD AN LIY:',
	'logo_article' => 'LOGO ATIK LA', # MODIF
	'logo_auteur' => 'LOGO LOTÈ', # MODIF
	'logo_rubrique' => 'LOGO RIBRIK', # MODIF
	'logo_site' => 'LOGO SIT LA', # MODIF
	'logo_standard_rubrique' => 'LOGO ODINÈ TOUT RIBRIK YO', # MODIF
	'logo_survol' => 'LOGO POU VOLE', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Chwa labaz w-a',
	'module_fichier_langue' => 'Fichye-lanng',
	'module_raccourci' => 'Tichemen',
	'module_texte_affiche' => 'Tèks ki afiche',
	'module_texte_explicatif' => 'W kapab mèt tout tichemen yo ki isit aprè, nan leskèlèt sa-yo ou sit piblik. Yo ké tradwi otomatikman nan diféran lanng, chak ki genyen yon fichye-lanng.',
	'module_texte_traduction' => 'fichye-lanng la « @module@ » se disponib nan :',
	'mois_non_connu' => 'ki pa koni',

	// O
	'onglet_repartition_actuelle' => 'kounye-a',

	// R
	'required' => '[Nésèsè]', # MODIF

	// S
	'statut_admin_restreint' => '(komandè ki limité)', # MODIF

	// T
	'taille_cache_image' => 'Tout imaj ki SPIP kav kalkile otomatikman (viyèt nan dokiman, kouman li rele ki pwézanté nan foma gwafik, tout fonksyon matematik nan foma TeX...) yo ka okipe nan répètwar @dir@ lespas total ki @taille@.',
	'taille_cache_octets' => 'Tay pou kach se aster @octets@.', # MODIF
	'taille_cache_vide' => 'Kach-la se vid.',
	'taille_repertoire_cache' => 'Latay répertwar kach',
	'text_article_propose_publication' => 'Atik ki pwopoze pou fé parèt. Ezit pas bay lavi aou nan fowom ki jwen atik-la (anba lapaj).', # MODIF
	'texte_acces_ldap_anonyme_1' => 'Kèk sèvè LDAP y ki pa aksepte laksé anonim.Alò, fòk pwezizél yon lidentifian pou lo promye aksé akoz aprèsa posib cheche tout enfò masyon w ka vle nan laniyé. Men souvan, genyen posib w kenbe tout chan la vid.',
	'texte_admin_effacer_01' => 'Komand la li efase <i>tout</i> kontni antye nan labazdone,
ak <i>tout</i> aksé rédaktè ak komanè yo. Si w te fé mache ali, fòk w enstalé  yon lòt fwa laprosédi
lenstalasyon SPIP pou w kreye yon lòt nouvo baz ak son promyé laksé komandè', # MODIF
	'texte_adresse_annuaire_1' => '(Si laniyé aw se enstalé sou mèm machin sévè sit aw, se posib li rele senpman «localhost».)',
	'texte_ajout_auteur' => 'Lotè-a te fin ajoute pou atik-la :',
	'texte_annuaire_ldap_1' => 'Si w gen laksé lanyiè (LDAP), w kapab itilize ali pou enpòte otomatikman itilizatè yo sou SPIP.', # MODIF
	'texte_article_statut' => 'Atik-la se :',
	'texte_article_virtuel' => 'Atik virtyel',
	'texte_article_virtuel_reference' => '<b>Atik virtyèl :</b> se yon atik ki referanse nan sit SPIP aw, men ki touné viré sou yon lòt URL. Pou efase touné-viré an, ann efas w URL isit anlèr.',
	'texte_aucun_resultat_auteur' => 'Pa oken rézilta pou "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Sit-la kapab bay w lalis redaktè an liy kounyen-a, bagay-la pèmè w voye mesaj direk ansamn moun. W pe chwazi pa parèt a liy nan lis-la (w kembe « envisib » pou tout zot itilizatè).', # MODIF
	'texte_auteurs' => 'LOTÈ YO',
	'texte_choix_base_1' => 'Ann chwazi labaz ou :',
	'texte_choix_base_2' => 'Sèvè SQL-la, li ka kembe kèk bazdoné.', # MODIF
	'texte_choix_base_3' => '<b>Chwazi</b> issit anba labaz ki lébérjè  te bay aw:',
	'texte_compte_element' => '@count@ eleman',
	'texte_compte_elements' => '@count@ eleman (yo)',
	'texte_connexion_mysql' => 'Gade tout lenfòmasyon lébèjè te bay aw : fòk w rankont tout kod pou koneksyon sou sèvè SQL la, si lébéjè kabab bay yon baz SQL.', # MODIF
	'texte_contenu_article' => '(kèk mo pou di ki latik-la ka kembe.)',
	'texte_contenu_articles' => 'Selon laspé sit piblik aw, posib chwazi kèk zéléman latik pa itil aw.
  Lalis isit anba pèmè w chwazi éléman sa-yo W ka kembe.
  ',
	'texte_crash_base' => 'Si bazdoné aw ki kraze,
   w kapab eséy yon aranjman
   otomatik.',
	'texte_creer_rubrique' => 'Avan w kapab ékri tout atik la,<br /> fòk w kreye yon ribrik dabò.',
	'texte_date_creation_article' => 'LADAT KRÉASYON LARTIK-LA :',
	'texte_date_publication_anterieure' => 'Ladat redaksyon davan :',
	'texte_date_publication_anterieure_nonaffichee' => 'Pa afiche yon dat redaksyon déyè.',
	'texte_date_publication_article' => 'LADAT PIBLIKASYON AN LIY :',
	'texte_descriptif_rapide' => 'Dekrisyon taptap',
	'texte_effacer_base' => 'Efase labazdoné SPIP',
	'texte_en_cours_validation' => 'Atik ak tinouvèl isit anba, zot se pwopoze pou fè parèt. Ezit pa bay lavi aw nan fowom jwen.', # MODIF
	'texte_enrichir_mise_a_jour' => 'W kapab rann laspé lapaj pli rich ak « tichemen tipografik ».',
	'texte_fichier_authent' => '<b>Fòk SPIP kreye fichye yo espesyal <tt>.htpasswd</tt>
  ak <tt>.htpasswd-admin</tt> nan repètwar @dossier@ ?</b><p>
  Fichye sa-yo pèmè w limite laksé lotè ak komandè nan kèk lòt katye sit-la
  (pwogwam lestatistik, pa egsanp).</p><p>
  W kapab sere lopsyon an nan valè otomatik (pou pa kreye tou fichye la), si li pa itil aw.  </p>', # MODIF
	'texte_informations_personnelles_1' => 'Sistèm ke jodiya kreye yon laksé pèsonalizé pou w.',
	'texte_informations_personnelles_2' => '(Gad : si genyen yon lòt enstalasyon ak laksé aw ka mache ankò, w kapab', # MODIF
	'texte_introductif_article' => '(Tèks lentwodiksyon latik.)',
	'texte_jeu_caractere' => 'Lopsyon-an se itil si sitweb-la afiche kèk alfabe diferan lalfabé
 romin (ou « oksidantal ») ek tout alfabe komsa.
 Alò, fòk w chanje reglaj otomatik pou chwazi yon gwoup karaktè pwop ;
 Se mye fè yon esey avan pou rankout yon manyen adapté pou afich lang-la
 Si ou chanje lalfabe a
 ann fé osi bo reglaj nan leskelèt sit w (baliz <tt>#CHARSET</tt>).', # MODIF
	'texte_login_ldap_1' => '(Kembe vid ali pou yo laksé anonim, osnon ekri w chemen konple pa egsanp « <tt>uid=mwen, ou=users, dc=sitamwen, dc=com</tt> ».)',
	'texte_login_precaution' => 'Atansyon ! bagay-la se nonkod koumon w rele kounyen-a.
 Ann itilize fòmilè-a ek swen...',
	'texte_mise_a_niveau_base_1' => 'W te fini renouvèle tout fichye SPIP.
 Fòk kembe nan nivo labazdoné
 pou sit-la.',
	'texte_modifier_article' => 'Chanje atik-la :',
	'texte_multilinguisme' => 'Si w vle itilize atik yo sous sit-la nan diferan lang, ak yon navigasyon konplèks,  w kapab ajoute yon meni-dewoulè pou chwazi lalang tout atik ak ribrik yo, selon kouman w te òganize sit aw.', # MODIF
	'texte_multilinguisme_trad' => 'Ou kap mèt yon sistèm pou okipe kèk lyen ant plizyè tradiksyon yon mèm atik.', # MODIF
	'texte_non_compresse' => '<i>ki pa konprese</i> (sèvè w ki pa soutni nan fonksyon la)',
	'texte_nouvelle_version_spip_1' => 'W te enstalé yon nouvo vésyon SPIP.',
	'texte_nouvelle_version_spip_2' => 'Fòk w fè yon arnouvèlman pli konple pou monte nivo nouvo vèsyon an. Si w se webmèt sit-la, mèsi efase fichye-a <tt>inc_connect.php3</tt> nan repetwar <tt>ecrire</tt> ak ropran lenstalasyon pou mèt paramèt koneksyon sou bazdone nan nivo.<p> (Gad. : si w te oubliye paramèt koneksyon aw, gad fichye <tt>inc_connect.php3</tt> avan efase ali...)</p>', # MODIF
	'texte_operation_echec' => 'Mèsi tounyen deyè sou paj davan, chwazi yon lòt baz osnon kreye w yon nouvo baz. Gad byin tout lenfòmasyon lébjèje w te bay aw.',
	'texte_plus_trois_car' => 'plisk 3 karaktè limprimi',
	'texte_plusieurs_articles' => 'Genyen kèk lotè pou "@cherche_auteur@":',
	'texte_port_annuaire' => '(Lavalè enskri otamatikman ka mache an jénéral.)',
	'texte_proposer_publication' => 'Kan latik fini,<br /> w kapab pwopoze ali pou yon piblikasyon.', # MODIF
	'texte_proxy' => 'Posib (intranet, rézo pwoteje...),
  se nésèsè itilize yon  pwoksi <i>proxy HTTP</i> pou konek tout sit sendike.
  Alò fòk w enskri ladrès URL, nan fòma
  <tt><html>http://proxy:8080</html></tt>. Nòmalman,
w ke sere chan-la vid.  ', # MODIF
	'texte_publication_articles_post_dates' => 'Kilès atitud SPIP ke chwazi pou pibliye  tout latik ki dat piblikasyon
  se présize nan dat lavenir ?',
	'texte_rappel_selection_champs' => '[Oubliy pa w chwazi chan la korekman.]',
	'texte_recalcul_page' => 'Si w vle
kalkil ankò yon sel paj selman, itilize plito lespas piblik ak bouton « Kalkil ankò ».',
	'texte_recuperer_base' => 'Aranje bazdoné la',
	'texte_reference_mais_redirige' => 'atik ki referanse nan sit SPIP aou, men ki viré direksyon sou yon lot URL.',
	'texte_requetes_echouent' => '<b>kank kèk rekèt SQL ki pa mache
  sistématikman ak ki pa rézon vizib, se posib bagay la ki ako bazdoné-la  li mèm
.</b><p>
  Tounyen a kapasité SQL pou aranje tout tab ali kank zot se abime pa aksidan.
W kapab esey issit yon aranjman ;
 Si bagay-la ki pa mache, kenbe ou yon kopi lafichaj, ki sere pètèt indis pou rannkont ki pa mache...</p><p>
  Si pwoblèm la ki kenbe, mèsi kontak lébérjè
.</p>', # MODIF
	'texte_selection_langue_principale' => 'W kapab chwazi  « lang prensipal » sit-la. Chwa-an se pa obligasyon - bon dié ! - w ékri artik-w nan lang-la, men bagay-la li pémè défini :
 <ul><li> fòma otomatik tout dat sou sit piblik ;</li>
 <li> ki mòtè tipografik, fòk sistèm SPIP li itilize pou rann tout tèks sou sit-la ;</li>
 <li> ki lang fòk sit itilize nan tout fòmilè sou sit piblik ;</li>
 <li> ki lang se prézanté otomatikman nan lespas privé.</li></ul>',
	'texte_sous_titre' => 'Soutitr (Kouman i relé osi)',
	'texte_statistiques_visites' => '(tout liy nwa :  dimanch / lakourb nwa : lévolisyon mwayenn sa)',
	'texte_statut_attente_validation' => 'ki tann pou konfimé',
	'texte_statut_publies' => 'pibliyé an liy',
	'texte_statut_refuses' => 'refizé',
	'texte_suppression_fichiers' => 'Itilize komand-la pou efase tout fichyé prézan sa-yo nan kach-SPIP (cache).
Bagay-la pémè, pa egsanp, fòse rekalkil tout paj sa-yo, apré plizyè gro chanjman nan grafism osnon lastrikti sit aou.
',
	'texte_sur_titre' => 'Sir-tit',
	'texte_table_ok' => ': tab-la se bon.',
	'texte_tentative_recuperation' => 'Esey aranjé',
	'texte_tenter_reparation' => 'Esèy yon aranjman labazdoné',
	'texte_test_proxy' => 'Pou eseye pwoksi-a (proxy), ann enskri isit ladrès yon sit web
    w vle testé.',
	'texte_titre_02' => 'Tit (Kouman i rele) :',
	'texte_titre_obligatoire' => '<b>Tit (Kouman i rele)</b> [Nèsèsè]', # MODIF
	'texte_travail_article' => '@nom_auteur_modif@ té travayé sou atik la  @date_diff@ minit pase',
	'texte_travail_collaboratif' => 'Si genyen souvan kèl redaktè ki soutni sou
  yon mèm atik, sistèm-la kapab afiche atik yo
  ki « ouvè »
 nan tan résan  pou evite chanjman ki kraze lòt.
 W kapab mèt opsyon-nan ki sispann otomatikman pou evite fè parèt toultan
   mesaj yo pou atansyon.
', # MODIF
	'texte_vide' => 'vid',
	'texte_vider_cache' => 'Vide kach-la',
	'titre_admin_tech' => 'Swen teknik',
	'titre_cadre_afficher_article' => 'Fè parèt atik yo',
	'titre_cadre_afficher_traductions' => 'Fè parèt kouman se tradiksyon yo pou tout lanng swivan :',
	'titre_cadre_ajouter_auteur' => 'KREYE YON LOTE :',
	'titre_cadre_interieur_rubrique' => 'nan ribrik',
	'titre_cadre_numero_auteur' => 'LOTE NIMEWO',
	'titre_cadre_signature_obligatoire' => '<b>Siyati</b> [Nésesè]<br />', # MODIF
	'titre_config_fonctions' => 'Konfigire sit-la',
	'titre_configuration' => 'Konfigire sit-la',
	'titre_connexion_ldap' => 'Opsyon sa-yo : <b>ou konèksyon LDAP</b>',
	'titre_groupe_mots' => 'GWOUP MOKLE :',
	'titre_langue_article' => 'LALANNG ATIK-LA', # MODIF
	'titre_langue_rubrique' => 'LALANNG RIBRIK-LA', # MODIF
	'titre_langue_trad_article' => 'LALANNG AK TRADIKSYON YO ATIK-LA',
	'titre_les_articles' => 'ATIK YO',
	'titre_naviguer_dans_le_site' => 'Fè yon vire sou sit-la...',
	'titre_nouvelle_rubrique' => 'Nouvo ribrik',
	'titre_numero_rubrique' => 'RIBRIK NIMEWO :',
	'titre_page_articles_edit' => 'Chanje: @titre@',
	'titre_page_articles_page' => 'Atik yo',
	'titre_page_articles_tous' => 'Tout sit sa-mèm',
	'titre_page_calendrier' => 'Kalandriye @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Konfigire sit-la',
	'titre_page_delete_all' => 'krazman konple ke pa posib pou anile',
	'titre_page_recherche' => 'Rezilta chèche @recherche@',
	'titre_page_statistiques_referers' => 'Rézilta estatistik (lyen sa-yo ka rive)',
	'titre_page_upgrade' => 'Mèt SPIP nan nivle',
	'titre_publication_articles_post_dates' => 'Piblikasyon tout atik yo posdate',
	'titre_reparation' => 'Reparasyon',
	'titre_suivi_petition' => 'Swiv tout petisyon yo',
	'trad_article_traduction' => 'Tout versyon pou atik la :',
	'trad_delier' => 'Retire lyen ansanm atik la ak tout tradidksyon', # MODIF
	'trad_lier' => 'Atik la se tradiksyon atik nimewo :',
	'trad_new' => 'Ekri tradiksyon ankò pou atik la', # MODIF
];
